@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class AsyncRecognitionTaskInfo(AbstractModel):
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
         self.Url = params.get("Url")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AsyncRecognitionTasks(AbstractModel):
@@ -58,6 +67,13 @@ class AsyncRecognitionTasks(AbstractModel):
                 obj = AsyncRecognitionTaskInfo()
                 obj._deserialize(item)
                 self.Tasks.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CloseAsyncRecognitionTaskRequest(AbstractModel):
@@ -75,6 +91,13 @@ class CloseAsyncRecognitionTaskRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CloseAsyncRecognitionTaskResponse(AbstractModel):
@@ -127,6 +150,13 @@ class CreateAsrVocabRequest(AbstractModel):
                 obj._deserialize(item)
                 self.WordWeights.append(obj)
         self.WordWeightStr = params.get("WordWeightStr")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateAsrVocabResponse(AbstractModel):
@@ -205,6 +235,13 @@ class CreateAsyncRecognitionTaskRequest(AbstractModel):
         self.ConvertNumMode = params.get("ConvertNumMode")
         self.WordInfo = params.get("WordInfo")
         self.HotwordId = params.get("HotwordId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateAsyncRecognitionTaskResponse(AbstractModel):
@@ -239,7 +276,7 @@ class CreateCustomizationRequest(AbstractModel):
         """
         :param ModelName: 自学习模型名称，需在1-20字符之间
         :type ModelName: str
-        :param TextUrl: 文本文件的下载地址，服务会从该地址下载文件， 以训练模型，目前仅支持腾讯云cos
+        :param TextUrl: 文本文件的下载地址，服务会从该地址下载文件，目前仅支持腾讯云cos
         :type TextUrl: str
         :param ModelType: 自学习模型类型，填写8k或者16k
         :type ModelType: str
@@ -257,6 +294,13 @@ class CreateCustomizationRequest(AbstractModel):
         self.TextUrl = params.get("TextUrl")
         self.ModelType = params.get("ModelType")
         self.TagInfos = params.get("TagInfos")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateCustomizationResponse(AbstractModel):
@@ -308,9 +352,9 @@ class CreateRecTaskRequest(AbstractModel):
         :type ResTextFormat: int
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
-        :param SpeakerDiarization: 是否开启说话人分离，0：不开启，1：开启(仅支持8k_zh，16k_zh，16k_zh_video引擎模型，单声道音频)
+        :param SpeakerDiarization: 是否开启说话人分离，0：不开启，1：开启(仅支持8k_zh，16k_zh，16k_zh_video引擎模型，单声道音频)，默认值为 0。
         :type SpeakerDiarization: int
-        :param SpeakerNumber: 说话人分离人数（需配合开启说话人分离使用），取值范围：0-10，0代表自动分离（目前仅支持≤6个人），1-10代表指定说话人数分离。
+        :param SpeakerNumber: 说话人分离人数（需配合开启说话人分离使用），取值范围：0-10，0代表自动分离（目前仅支持≤6个人），1-10代表指定说话人数分离。默认值为 0。
 注：话者分离目前是beta版本，请根据您的需要谨慎使用
         :type SpeakerNumber: int
         :param CallbackUrl: 回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。回调格式&内容详见：[录音识别回调说明](https://cloud.tencent.com/document/product/1093/52632)
@@ -325,13 +369,13 @@ class CreateRecTaskRequest(AbstractModel):
         :type HotwordId: str
         :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
         :type FilterDirty: int
-        :param FilterModal: 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
+        :param FilterModal: 是否过滤语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
         :type FilterModal: int
         :param ConvertNumMode: 是否进行阿拉伯数字智能转换（目前支持中文普通话引擎）。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字，3: 打开数学相关数字转换。默认值为 1。
         :type ConvertNumMode: int
-        :param Extra: 附加参数
+        :param Extra: 附加参数(该参数无意义，忽略即可)
         :type Extra: str
-        :param FilterPunc: 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认为0。
+        :param FilterPunc: 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认值为 0。
         :type FilterPunc: int
         """
         self.EngineModelType = None
@@ -369,6 +413,13 @@ class CreateRecTaskRequest(AbstractModel):
         self.ConvertNumMode = params.get("ConvertNumMode")
         self.Extra = params.get("Extra")
         self.FilterPunc = params.get("FilterPunc")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateRecTaskResponse(AbstractModel):
@@ -409,6 +460,13 @@ class DeleteAsrVocabRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.VocabId = params.get("VocabId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteAsrVocabResponse(AbstractModel):
@@ -443,6 +501,13 @@ class DeleteCustomizationRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ModelId = params.get("ModelId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteCustomizationResponse(AbstractModel):
@@ -507,6 +572,13 @@ class DescribeTaskStatusRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTaskStatusResponse(AbstractModel):
@@ -547,6 +619,13 @@ class DownloadAsrVocabRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.VocabId = params.get("VocabId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DownloadAsrVocabResponse(AbstractModel):
@@ -589,6 +668,13 @@ class DownloadCustomizationRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ModelId = params.get("ModelId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DownloadCustomizationResponse(AbstractModel):
@@ -635,6 +721,13 @@ class GetAsrVocabListRequest(AbstractModel):
         self.TagInfos = params.get("TagInfos")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetAsrVocabListResponse(AbstractModel):
@@ -682,6 +775,13 @@ class GetAsrVocabRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.VocabId = params.get("VocabId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetAsrVocabResponse(AbstractModel):
@@ -743,9 +843,9 @@ class GetCustomizationListRequest(AbstractModel):
         """
         :param TagInfos: 标签信息，格式为“$TagKey : $TagValue ”，中间分隔符为“空格”+“:”+“空格”
         :type TagInfos: list of str
-        :param Limit: 分页大小
+        :param Limit: 分页大小，默认1000
         :type Limit: int
-        :param Offset: 分页offset
+        :param Offset: 分页offset，默认0
         :type Offset: int
         """
         self.TagInfos = None
@@ -757,6 +857,13 @@ class GetCustomizationListRequest(AbstractModel):
         self.TagInfos = params.get("TagInfos")
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetCustomizationListResponse(AbstractModel):
@@ -810,6 +917,13 @@ class HotWord(AbstractModel):
     def _deserialize(self, params):
         self.Word = params.get("Word")
         self.Weight = params.get("Weight")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Model(AbstractModel):
@@ -856,6 +970,13 @@ class Model(AbstractModel):
         self.ModelState = params.get("ModelState")
         self.AtUpdated = params.get("AtUpdated")
         self.TagInfos = params.get("TagInfos")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyCustomizationRequest(AbstractModel):
@@ -885,6 +1006,13 @@ class ModifyCustomizationRequest(AbstractModel):
         self.ModelName = params.get("ModelName")
         self.ModelType = params.get("ModelType")
         self.TextUrl = params.get("TextUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyCustomizationResponse(AbstractModel):
@@ -923,6 +1051,13 @@ class ModifyCustomizationStateRequest(AbstractModel):
     def _deserialize(self, params):
         self.ModelId = params.get("ModelId")
         self.ToState = params.get("ToState")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyCustomizationStateResponse(AbstractModel):
@@ -997,6 +1132,13 @@ class SentenceDetail(AbstractModel):
                 obj._deserialize(item)
                 self.Words.append(obj)
         self.SpeechSpeed = params.get("SpeechSpeed")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SentenceRecognitionRequest(AbstractModel):
@@ -1036,15 +1178,15 @@ class SentenceRecognitionRequest(AbstractModel):
         :type DataLen: int
         :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
         :type HotwordId: str
-        :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。
+        :param FilterDirty: 是否过滤脏词（目前支持中文普通话引擎）。0：不过滤脏词；1：过滤脏词；2：将脏词替换为 * 。默认值为 0。
         :type FilterDirty: int
-        :param FilterModal: 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。
+        :param FilterModal: 是否过语气词（目前支持中文普通话引擎）。0：不过滤语气词；1：部分过滤；2：严格过滤 。默认值为 0。
         :type FilterModal: int
-        :param FilterPunc: 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认为0。
+        :param FilterPunc: 是否过滤标点符号（目前支持中文普通话引擎）。 0：不过滤，1：过滤句末标点，2：过滤所有标点。默认值为 0。
         :type FilterPunc: int
-        :param ConvertNumMode: 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1
+        :param ConvertNumMode: 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1。
         :type ConvertNumMode: int
-        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。支持引擎8k_zh，16k_zh，16k_en，16k_ca，16k_ja，16k_wuu-SH
+        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。支持引擎8k_zh，16k_zh，16k_en，16k_ca，16k_ja，16k_wuu-SH。默认值为 0。
         :type WordInfo: int
         """
         self.ProjectId = None
@@ -1080,6 +1222,13 @@ class SentenceRecognitionRequest(AbstractModel):
         self.FilterPunc = params.get("FilterPunc")
         self.ConvertNumMode = params.get("ConvertNumMode")
         self.WordInfo = params.get("WordInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SentenceRecognitionResponse(AbstractModel):
@@ -1145,6 +1294,13 @@ class SentenceWord(AbstractModel):
         self.Word = params.get("Word")
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SentenceWords(AbstractModel):
@@ -1173,6 +1329,13 @@ class SentenceWords(AbstractModel):
         self.Word = params.get("Word")
         self.OffsetStartMs = params.get("OffsetStartMs")
         self.OffsetEndMs = params.get("OffsetEndMs")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SetVocabStateRequest(AbstractModel):
@@ -1194,6 +1357,13 @@ class SetVocabStateRequest(AbstractModel):
     def _deserialize(self, params):
         self.VocabId = params.get("VocabId")
         self.State = params.get("State")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SetVocabStateResponse(AbstractModel):
@@ -1232,6 +1402,13 @@ class Task(AbstractModel):
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TaskStatus(AbstractModel):
@@ -1275,6 +1452,13 @@ class TaskStatus(AbstractModel):
                 obj = SentenceDetail()
                 obj._deserialize(item)
                 self.ResultDetail.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateAsrVocabRequest(AbstractModel):
@@ -1286,14 +1470,14 @@ class UpdateAsrVocabRequest(AbstractModel):
         """
         :param VocabId: 热词表ID
         :type VocabId: str
-        :param Name: 热词表名称
+        :param Name: 热词表名称，长度在1-255之间
         :type Name: str
         :param WordWeights: 词权重数组，包含全部的热词和对应的权重。每个热词的长度不大于10，权重为[1,10]之间整数，数组长度不大于128
         :type WordWeights: list of HotWord
         :param WordWeightStr: 词权重文件（纯文本文件）的二进制base64编码，以行分隔，每行的格式为word|weight，即以英文符号|为分割，左边为词，右边为权重，如：你好|5。
 当用户传此参数（参数长度大于0），即以此参数解析词权重，WordWeights会被忽略
         :type WordWeightStr: str
-        :param Description: 热词表描述
+        :param Description: 热词表描述，长度在0-1000之间
         :type Description: str
         """
         self.VocabId = None
@@ -1314,6 +1498,13 @@ class UpdateAsrVocabRequest(AbstractModel):
                 self.WordWeights.append(obj)
         self.WordWeightStr = params.get("WordWeightStr")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateAsrVocabResponse(AbstractModel):
@@ -1385,4 +1576,11 @@ class Vocab(AbstractModel):
         self.CreateTime = params.get("CreateTime")
         self.UpdateTime = params.get("UpdateTime")
         self.State = params.get("State")
-        self.TagInfos = params.get("TagInfos")
\ No newline at end of file
+        self.TagInfos = params.get("TagInfos")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
